@@ -1,27 +1,18 @@
 /*
-  This class represents a DCC transferlist model.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
-
-/*
-  Copyright (C) 2009,2010 Bernd Buschinski <b.buschinski@web.de>
+    SPDX-FileCopyrightText: 2009, 2010 Bernd Buschinski <b.buschinski@web.de>
 */
 
 #include "transferlistmodel.h"
 
-#include <QApplication>
-#include <QDebug>
+#include "konversation_log.h"
 
 #include <KCategorizedSortFilterProxyModel>
 #include <KLocalizedString>
 #include <KCategoryDrawer>
-#include <KIconLoader>
+
+#include <QApplication>
 
 namespace Konversation
 {
@@ -68,7 +59,7 @@ namespace Konversation
             int height;
             QFontMetrics metrics(option.font);
 
-            int width = metrics.width(index.data(Qt::DisplayRole).toString());
+            int width = metrics.horizontalAdvance(index.data(Qt::DisplayRole).toString());
 
             if (itemType == TransferItemData::SendCategory || itemType == TransferItemData::ReceiveCategory)
             {
@@ -124,18 +115,17 @@ namespace Konversation
                     return;
                 }
             }
-            QStyleOptionViewItemV4 _option(option);
-            QStyle* style = _option.widget ? _option.widget->style() : QApplication::style();
-            style->drawPrimitive(QStyle::PE_PanelItemViewItem, &_option, painter, _option.widget);
+            QStyle* style = option.widget ? option.widget->style() : QApplication::style();
+            style->drawPrimitive(QStyle::PE_PanelItemViewItem, &option, painter, option.widget);
 
             QStyleOptionProgressBar progressBarOption;
-            progressBarOption.rect = _option.rect;
+            progressBarOption.rect = option.rect;
             progressBarOption.minimum = 0;
             progressBarOption.maximum = 100;
             progressBarOption.progress = index.data().toInt();
-            progressBarOption.text = QString::number(progressBarOption.progress) + '%';
+            progressBarOption.text = QString::number(progressBarOption.progress) + QLatin1Char('%');
             progressBarOption.textVisible = true;
-            progressBarOption.state = _option.state;
+            progressBarOption.state = option.state;
 
             style->drawControl(QStyle::CE_ProgressBar, &progressBarOption, painter);
         }
@@ -190,8 +180,8 @@ namespace Konversation
 
             if (item.transfer)
             {
-                connect (item.transfer, SIGNAL(statusChanged(Konversation::DCC::Transfer*,int,int)),
-                         this, SLOT(transferStatusChanged(Konversation::DCC::Transfer*,int,int)));
+                connect (item.transfer, &Transfer::statusChanged,
+                         this, &TransferListModel::transferStatusChanged);
             }
         }
 
@@ -250,7 +240,7 @@ namespace Konversation
                 return headerData(index.column(), Qt::Horizontal, role);
             }
 
-            Transfer *transfer = 0;
+            Transfer *transfer = nullptr;
             if (m_transferList[index.row()].displayType == TransferItemData::ReceiveItem ||
                 m_transferList[index.row()].displayType == TransferItemData::SendItem)
             {
@@ -276,7 +266,7 @@ namespace Konversation
                         case TransferHeaderData::Progress:
                             return transfer->getProgress();
                         case TransferHeaderData::OfferDate:
-                            return transfer->getTimeOffer().toString("hh:mm:ss");
+                            return transfer->getTimeOffer().toString(QStringLiteral("hh:mm:ss"));
                         case TransferHeaderData::Position:
                             return getPositionPrettyText(transfer->getTransferringPosition(),
                                                          transfer->getFileSize());
@@ -290,7 +280,8 @@ namespace Konversation
                             return getTimeLeftPrettyText(transfer->getTimeLeft());
 
                         default:
-                            qDebug() << "unknown columntype: " << type;
+                            qCDebug(KONVERSATION_LOG) << "unknown columntype: " << type;
+                            Q_FALLTHROUGH();
                         case TransferHeaderData::TypeIcon:
                             return QVariant();
                     };
@@ -302,7 +293,7 @@ namespace Konversation
                 case TransferStatus:
                     return transfer->getStatus();
                 case TransferPointer:
-                    return qVariantFromValue<QObject*>(transfer);
+                    return QVariant::fromValue<QObject*>(transfer);
                 case TransferProgress:
                     return transfer->getProgress();
                 case TransferOfferDate:
@@ -314,15 +305,11 @@ namespace Konversation
                     {
                         case TransferHeaderData::Status:
                         {
-                            QVariant decoration(QVariant::Pixmap);
-                            decoration.setValue<QPixmap>(getStatusIcon(transfer->getStatus()));
-                            return decoration;
+                            return getStatusIcon(transfer->getStatus());
                         }
                         case TransferHeaderData::TypeIcon:
                         {
-                            QVariant decoration(QVariant::Pixmap);
-                            decoration.setValue<QPixmap>(getTypeIcon(transfer->getType()));
-                            return decoration;
+                            return QIcon::fromTheme((transfer->getType() == Transfer::Send) ? QStringLiteral("arrow-up") : QStringLiteral("arrow-down"));
                         }
                         default:
                             return QVariant();
@@ -342,10 +329,10 @@ namespace Konversation
                             tooltip = transfer->getPartnerNick();
                             break;
                         case TransferHeaderData::Progress:
-                            tooltip = QString::number(transfer->getProgress()) + '%';
+                            tooltip = QString::number(transfer->getProgress()) + QLatin1Char('%');
                             break;
                         case TransferHeaderData::OfferDate:
-                            tooltip = transfer->getTimeOffer().toString("hh:mm:ss");
+                            tooltip = transfer->getTimeOffer().toString(QStringLiteral("hh:mm:ss"));
                             break;
                         case TransferHeaderData::Position:
                             tooltip = getPositionPrettyText(transfer->getTransferringPosition(),
@@ -367,7 +354,7 @@ namespace Konversation
                             tooltip = displayTypeToString(m_transferList[index.row()].displayType);
                             break;
                         default:
-                            qDebug() << "unknown columntype: " << type;
+                            qCDebug(KONVERSATION_LOG) << "unknown columntype: " << type;
                             break;
                     };
 
@@ -385,52 +372,40 @@ namespace Konversation
             }
         }
 
-        QPixmap TransferListModel::getTypeIcon(Transfer::Type type) const
-        {
-            if (type == Transfer::Send)
-            {
-                return KIconLoader::global()->loadIcon("arrow-up", KIconLoader::Small);
-            }
-            else
-            {
-                return KIconLoader::global()->loadIcon("arrow-down", KIconLoader::Small);
-            }
-        }
-
-        QPixmap TransferListModel::getStatusIcon(Transfer::Status status) const
+        QIcon TransferListModel::getStatusIcon(Transfer::Status status) const
         {
             QString icon;
             switch (status)
             {
                 case Transfer::Queued:
-                    icon = "media-playback-stop";
+                    icon = QStringLiteral("media-playback-stop");
                     break;
                 case Transfer::Preparing:
                 case Transfer::WaitingRemote:
                 case Transfer::Connecting:
-                    icon = "network-disconnect";
+                    icon = QStringLiteral("network-disconnect");
                     break;
                 case Transfer::Transferring:
-                    icon = "media-playback-start";
+                    icon = QStringLiteral("media-playback-start");
                     break;
                 case Transfer::Done:
-                    icon = "dialog-ok";
+                    icon = QStringLiteral("dialog-ok");
                     break;
                 case Transfer::Aborted:
                 case Transfer::Failed:
-                    icon = "process-stop";
+                    icon = QStringLiteral("process-stop");
                     break;
                 default:
                 break;
             }
-            return KIconLoader::global()->loadIcon(icon, KIconLoader::Small);
+            return QIcon::fromTheme(icon);
         }
 
         QString TransferListModel::getSpeedPrettyText (transferspeed_t speed)
         {
             if (speed == Transfer::Calculating || speed == Transfer::InfiniteValue)
             {
-                return QString("?");
+                return QStringLiteral("?");
             }
             else if (speed == Transfer::NotInTransfer)
             {
@@ -445,18 +420,18 @@ namespace Konversation
         QString TransferListModel::getPositionPrettyText(KIO::fileoffset_t position,
                                                          KIO::filesize_t filesize) const
         {
-            return KIO::convertSize(position) + " / " + KIO::convertSize(filesize);
+            return KIO::convertSize(position) + QLatin1String(" / ") + KIO::convertSize(filesize);
         }
 
         QString TransferListModel::getSenderAddressPrettyText(Transfer *transfer) const
         {
             if (transfer->getType() == Transfer::Send)
             {
-                return QString("%1:%2").arg(transfer->getOwnIp()).arg(transfer->getOwnPort());
+                return QStringLiteral("%1:%2").arg(transfer->getOwnIp()).arg(transfer->getOwnPort());
             }
             else
             {
-                return QString("%1:%2").arg(transfer->getPartnerIp()).arg(transfer->getPartnerPort());
+                return QStringLiteral("%1:%2").arg(transfer->getPartnerIp()).arg(transfer->getPartnerPort());
             }
         }
 
@@ -465,7 +440,7 @@ namespace Konversation
             switch (timeleft)
             {
                 case Transfer::InfiniteValue:
-                    return QString('?');
+                    return QStringLiteral("?");
                 default:
                     return secToHMS(timeleft);
                 case Transfer::NotInTransfer:
@@ -482,10 +457,10 @@ namespace Konversation
             remSec -= remMin * 60;
 
             // remHour can be more than 25, so we can't use QTime here.
-            return QString("%1:%2:%3")
-                .arg(QString::number(remHour).rightJustified(2, '0', false))
-                .arg(QString::number(remMin).rightJustified(2, '0'))
-                .arg(QString::number(remSec).rightJustified(2, '0'));
+            return QStringLiteral("%1:%2:%3")
+                .arg(QString::number(remHour).rightJustified(2, QLatin1Char('0'), false),
+                     QString::number(remMin).rightJustified(2, QLatin1Char('0')),
+                     QString::number(remSec).rightJustified(2, QLatin1Char('0')));
         }
 
         QString TransferListModel::getStatusText(Transfer::Status status, Transfer::Type type)
@@ -508,7 +483,7 @@ namespace Konversation
                         case Transfer::Send:
                             return i18n("Sending");
                         default:
-                            qDebug() << "unknown type: " << type;
+                            qCDebug(KONVERSATION_LOG) << "unknown type: " << type;
                             return QString();
                     }
                 case Transfer::Done:
@@ -518,7 +493,7 @@ namespace Konversation
                 case Transfer::Aborted:
                     return i18n("Aborted");
                 default:
-                    qDebug() << "unknown status: " << status;
+                    qCDebug(KONVERSATION_LOG) << "unknown status: " << status;
                     return QString();
             }
         }
@@ -537,7 +512,7 @@ namespace Konversation
                         case Transfer::Send:
                             return i18n("Preparing - Transfer is acquiring the data to send");
                         default:
-                            qDebug() << "unknown type: " << type;
+                            qCDebug(KONVERSATION_LOG) << "unknown type: " << type;
                             return QString();
                     }
                 case Transfer::WaitingRemote:
@@ -552,7 +527,7 @@ namespace Konversation
                         case Transfer::Send:
                             return i18n("Sending - Transfer is sending data to partner");
                         default:
-                            qDebug() << "unknown type: " << type;
+                            qCDebug(KONVERSATION_LOG) << "unknown type: " << type;
                             return QString();
                     }
                 case Transfer::Done:
@@ -569,7 +544,7 @@ namespace Konversation
                 case Transfer::Aborted:
                     return i18n("Aborted - Transfer was aborted by the User");
                 default:
-                    qDebug() << "unknown status: " << status;
+                    qCDebug(KONVERSATION_LOG) << "unknown status: " << status;
                     return QString();
             }
         }
@@ -646,8 +621,7 @@ namespace Konversation
         int TransferListModel::itemCount (TransferItemData::ItemDisplayType displaytype) const
         {
             int count = 0;
-            foreach (const TransferItemData &item, m_transferList)
-            {
+            for (const TransferItemData &item : m_transferList) {
                 if (item.displayType == displaytype)
                 {
                     ++count;
