@@ -1,23 +1,14 @@
 /*
-  send a file on DCC protocol
-  begin:     Mit Aug 7 2002
-  copyright: (C) 2002 by Dario Abatianni
-  email:     eisfuchs@tigress.com
-*/
-/*
-  Copyright (C) 2004-2007 Shintaro Matsuoka <shin@shoegazed.org>
-  Copyright (C) 2004,2005 John Tapsell <john@geola.co.uk>
-  Copyright (C) 2009 Michael Kreitzer <mrgrim@gr1m.org>
-  Copyright (C) 2009 Bernd Buschinski <b.buschinski@web.de>
-*/
-/*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
+    SPDX-License-Identifier: GPL-2.0-or-later
+
+    SPDX-FileCopyrightText: 2002 Dario Abatianni <eisfuchs@tigress.com>
+    SPDX-FileCopyrightText: 2004-2007 Shintaro Matsuoka <shin@shoegazed.org>
+    SPDX-FileCopyrightText: 2004, 2005 John Tapsell <john@geola.co.uk>
+    SPDX-FileCopyrightText: 2009 Michael Kreitzer <mrgrim@gr1m.org>
+    SPDX-FileCopyrightText: 2009 Bernd Buschinski <b.buschinski@web.de>
 */
 
-#include <qglobal.h>
+#include <QtGlobal>
 
 #ifdef Q_OS_WIN
 // Prevent windows system header files from defining min/max as macros.
@@ -32,8 +23,8 @@
 #include "connectionmanager.h"
 #include "server.h"
 #include "upnprouter.h"
+#include "konversation_log.h"
 
-#include <QFile>
 #include <QTimer>
 #include <QTcpSocket>
 #include <QTcpServer>
@@ -54,11 +45,11 @@ namespace Konversation
         TransferSend::TransferSend(QObject *parent)
             : Transfer(Transfer::Send, parent)
         {
-            qDebug();
+            qCDebug(KONVERSATION_LOG) << __FUNCTION__;
 
-            m_serverSocket = 0;
-            m_sendSocket = 0;
-            m_tmpFile = 0;
+            m_serverSocket = nullptr;
+            m_sendSocket = nullptr;
+            m_tmpFile = nullptr;
 
             m_connectionTimer = new QTimer(this);
             m_connectionTimer->setSingleShot(true);
@@ -75,29 +66,29 @@ namespace Konversation
 
         void TransferSend::cleanUp()
         {
-            qDebug();
+            qCDebug(KONVERSATION_LOG) << __FUNCTION__;
 
             stopConnectionTimer();
-            disconnect(m_connectionTimer, 0, 0, 0);
+            disconnect(m_connectionTimer, nullptr, nullptr, nullptr);
 
             finishTransferLogger();
             if (m_tmpFile)
             {
                 delete m_tmpFile;
-                m_tmpFile = 0;
+                m_tmpFile = nullptr;
             }
 
             m_file.close();
             if (m_sendSocket)
             {
-                disconnect(m_sendSocket, 0, 0, 0);
+                disconnect(m_sendSocket, nullptr, nullptr, nullptr);
                 m_sendSocket->close();
-                m_sendSocket = 0;                         // the instance will be deleted automatically by its parent
+                m_sendSocket = nullptr;                         // the instance will be deleted automatically by its parent
             }
             if (m_serverSocket)
             {
                 m_serverSocket->close();
-                m_serverSocket = 0;                       // the instance will be deleted automatically by its parent
+                m_serverSocket = nullptr;                       // the instance will be deleted automatically by its parent
 
                 if (Preferences::self()->dccUPnP())
                 {
@@ -153,7 +144,7 @@ namespace Konversation
 
         bool TransferSend::queue()
         {
-            qDebug();
+            qCDebug(KONVERSATION_LOG) << __FUNCTION__;
 
             if (getStatus() != Configuring)
             {
@@ -165,7 +156,7 @@ namespace Konversation
                 m_ownIp = DccCommon::getOwnIp(Application::instance()->getConnectionManager()->getServerByConnectionId(m_connectionId));
             }
 
-            if (!KAuthorized::authorizeAction("allow_downloading"))
+            if (!KAuthorized::authorizeAction(QStringLiteral("allow_downloading")))
             {
                 //Do not have the rights to send the file.  Shouldn't have gotten this far anyway
                 //Note this is after the initialisation so the view looks correct still
@@ -184,10 +175,10 @@ namespace Konversation
             }
 
             m_fastSend = Preferences::self()->dccFastSend();
-            qDebug() << "Fast DCC send: " << m_fastSend;
+            qCDebug(KONVERSATION_LOG) << "Fast DCC send: " << m_fastSend;
 
             //Check the file exists
-            KIO::StatJob* statJob = KIO::stat(m_fileURL, KIO::StatJob::SourceSide, 0);
+            KIO::StatJob* statJob = KIO::statDetails(m_fileURL, KIO::StatJob::SourceSide, KIO::StatNoDetails);
             statJob->exec();
             if (statJob->error())
             {
@@ -199,7 +190,7 @@ namespace Konversation
             if (m_fileName.isEmpty())
             {
                 bool pressedOk;
-                m_fileName = QInputDialog::getText(0, i18n("Enter Filename"),
+                m_fileName = QInputDialog::getText(nullptr, i18n("Enter Filename"),
                                                    i18n("<qt>The file that you are sending to <i>%1</i> does not have a filename.<br/>Please enter a filename to be presented to the receiver, or cancel the dcc transfer</qt>", getPartnerNick()),
                                                    QLineEdit::EchoMode::Normal, i18n("unknown"),
                                                    &pressedOk);
@@ -212,10 +203,10 @@ namespace Konversation
             }
 
             //FIXME: if "\\\"" works well on other IRC clients, replace "\"" with "\\\""
-            m_fileName.replace('\"', '_');
+            m_fileName.replace(QLatin1Char('\"'), QLatin1Char('_'));
             if (Preferences::self()->dccSpaceToUnderscore())
             {
-                m_fileName.replace(' ', '_');
+                m_fileName.replace(QLatin1Char(' '), QLatin1Char('_'));
             }
 
             if (!m_fileURL.isLocalFile())
@@ -233,17 +224,17 @@ namespace Konversation
                 return false; // not ready to send yet
             }
 
-            slotLocalCopyReady(0);
+            slotLocalCopyReady(nullptr);
             return true;
         }
 
         void TransferSend::slotLocalCopyReady(KJob *job)
         {
             QString fn = m_fileURL.toDisplayString();
-            bool remoteFile = job != 0;
+            bool remoteFile = job != nullptr;
             int error = job ? job->error() : 0;
 
-            qDebug() << "m_tmpFile: " << fn << "error: " << error << "remote file: " << remoteFile;
+            qCDebug(KONVERSATION_LOG) << "m_tmpFile: " << fn << "error: " << error << "remote file: " << remoteFile;
 
             if (error)
             {
@@ -264,7 +255,7 @@ namespace Konversation
             {
                 m_fileSize = m_file.size();
 
-                qDebug() << "filesize 0, new filesize: " << m_fileSize;
+                qCDebug(KONVERSATION_LOG) << "filesize 0, new filesize: " << m_fileSize;
 
                 if (m_fileSize == 0)
                 {
@@ -282,14 +273,14 @@ namespace Konversation
 
         void TransferSend::reject()
         {
-            qDebug();
+            qCDebug(KONVERSATION_LOG) << __FUNCTION__;
 
             failed(i18n("DCC SEND request was rejected"));
         }
 
         void TransferSend::abort()                     // public slot
         {
-            qDebug();
+            qCDebug(KONVERSATION_LOG) << __FUNCTION__;
 
             cleanUp();
             setStatus(Aborted);
@@ -298,7 +289,7 @@ namespace Konversation
 
         void TransferSend::start()                     // public slot
         {
-            qDebug();
+            qCDebug(KONVERSATION_LOG) << __FUNCTION__;
 
             if (getStatus() != Queued)
             {
@@ -310,7 +301,7 @@ namespace Konversation
             Server *server = Application::instance()->getConnectionManager()->getServerByConnectionId(m_connectionId);
             if (!server)
             {
-                qDebug() << "could not retrieve the instance of Server. Connection id: " << m_connectionId;
+                qCDebug(KONVERSATION_LOG) << "could not retrieve the instance of Server. Connection id: " << m_connectionId;
                 failed(i18n("Could not send a DCC SEND request to the partner via the IRC server."));
                 return;
             }
@@ -318,7 +309,7 @@ namespace Konversation
             if (!m_reverse)
             {
                 // Normal DCC SEND
-                qDebug() << "normal DCC SEND";
+                qCDebug(KONVERSATION_LOG) << "normal DCC SEND";
 
                 // Set up server socket
                 QString failedReason;
@@ -342,7 +333,7 @@ namespace Konversation
                 // Get own port number
                 m_ownPort = m_serverSocket->serverPort();
 
-                qDebug() << "Own Address=" << m_ownIp << ":" << m_ownPort;
+                qCDebug(KONVERSATION_LOG) << "Own Address=" << m_ownIp << ":" << m_ownPort;
 
                 if (Preferences::self()->dccUPnP())
                 {
@@ -365,13 +356,13 @@ namespace Konversation
             else
             {
                 // Passive DCC SEND
-                qDebug() << "Passive DCC SEND";
+                qCDebug(KONVERSATION_LOG) << "Passive DCC SEND";
 
                 int tokenNumber = Application::instance()->getDccTransferManager()->generateReverseTokenNumber();
                 // TODO: should we append a letter "T" to this token?
                 m_reverseToken = QString::number(tokenNumber);
 
-                qDebug() << "Passive DCC key(token): " << m_reverseToken;
+                qCDebug(KONVERSATION_LOG) << "Passive DCC key(token): " << m_reverseToken;
 
                 startConnectionTimer(Preferences::self()->dccSendTimeout());
 
@@ -386,7 +377,7 @@ namespace Konversation
             Server *server = Application::instance()->getConnectionManager()->getServerByConnectionId(m_connectionId);
             if (!server)
             {
-                qDebug() << "could not retrieve the instance of Server. Connection id: " << m_connectionId;
+                qCDebug(KONVERSATION_LOG) << "could not retrieve the instance of Server. Connection id: " << m_connectionId;
                 failed(i18n("Could not send a DCC SEND request to the partner via the IRC server."));
                 return;
             }
@@ -395,7 +386,8 @@ namespace Konversation
             {
                 if (port != m_ownPort) return; // Somebody elses forward succeeded
 
-                disconnect(this->sender(), SIGNAL(forwardComplete(bool,quint16)), this, SLOT(sendRequest(bool,quint16)));
+                auto* router = qobject_cast<UPnP::UPnPRouter*>(this->sender());
+                disconnect(router, &UPnPRouter::forwardComplete, this, &TransferSend::sendRequest);
 
                 if (error)
                 {
@@ -410,7 +402,7 @@ namespace Konversation
 
         void TransferSend::connectToReceiver(const QString &partnerHost, quint16 partnerPort)
         {
-            qDebug() << "host:" << partnerHost << "port:" << partnerPort;
+            qCDebug(KONVERSATION_LOG) << "host:" << partnerHost << "port:" << partnerPort;
             // Reverse DCC
 
             startConnectionTimer(Preferences::self()->dccSendTimeout());
@@ -421,7 +413,11 @@ namespace Konversation
             m_sendSocket = new QTcpSocket(this);
 
             connect(m_sendSocket, &QTcpSocket::connected, this, &TransferSend::startSending);
-            connect(m_sendSocket, static_cast<void (QTcpSocket::*)(QAbstractSocket::SocketError)>(&QTcpSocket::error), this, &TransferSend::slotGotSocketError);
+#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
+            connect(m_sendSocket, &QTcpSocket::errorOccurred, this, &TransferSend::slotGotSocketError);
+#else
+            connect(m_sendSocket, QOverload<QAbstractSocket::SocketError>::of(&QTcpSocket::error), this, &TransferSend::slotGotSocketError);
+#endif
 
             setStatus(Connecting);
 
@@ -430,7 +426,7 @@ namespace Konversation
                                                           // public
         bool TransferSend::setResume(quint64 position)
         {
-            qDebug() << "Position=" << position;
+            qCDebug(KONVERSATION_LOG) << "Position=" << position;
 
             if (getStatus() > WaitingRemote)
             {
@@ -451,7 +447,7 @@ namespace Konversation
         {
             // Normal DCC
 
-            qDebug();
+            qCDebug(KONVERSATION_LOG) << __FUNCTION__;
 
             stopConnectionTimer();
 
@@ -461,11 +457,15 @@ namespace Konversation
                 failed(i18n("Could not accept the connection (socket error)."));
                 return;
             }
-            connect(m_sendSocket, static_cast<void (QTcpSocket::*)(QAbstractSocket::SocketError)>(&QTcpSocket::error), this, &TransferSend::slotGotSocketError);
+#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
+            connect(m_sendSocket, &QTcpSocket::errorOccurred, this, &TransferSend::slotGotSocketError);
+#else
+            connect(m_sendSocket, QOverload<QAbstractSocket::SocketError>::of(&QTcpSocket::error), this, &TransferSend::slotGotSocketError);
+#endif
 
             // we don't need ServerSocket anymore
             m_serverSocket->close();
-            m_serverSocket = 0; // the instance will be deleted automatically by its parent
+            m_serverSocket = nullptr; // the instance will be deleted automatically by its parent
 
             if (Preferences::self()->dccUPnP())
             {
@@ -514,7 +514,7 @@ namespace Konversation
                 if ((KIO::fileoffset_t)m_fileSize <= m_transferringPosition)
                 {
                     Q_ASSERT((KIO::fileoffset_t)m_fileSize == m_transferringPosition);
-                    qDebug() << "Done.";
+                    qCDebug(KONVERSATION_LOG) << "Done.";
                 }
             }
 
@@ -533,7 +533,7 @@ namespace Konversation
 
         void TransferSend::writeData()                 // slot
         {
-            //qDebug();
+            //qCDebug(KONVERSATION_LOG) << __FUNCTION__;
 
             qint64 actual = m_file.read(m_buffer, m_bufferSize);
             if (actual > 0)
@@ -544,7 +544,7 @@ namespace Konversation
 
         void TransferSend::getAck()                    // slot
         {
-            //qDebug();
+            //qCDebug(KONVERSATION_LOG) << __FUNCTION__;
             if (m_transferringPosition < (KIO::fileoffset_t)m_fileSize)
             {
                 //don't write data directly, in case we get spammed with ACK we try so send too fast
@@ -557,10 +557,10 @@ namespace Konversation
                 m_sendSocket->read((char*)&pos, 4);
                 pos = ntohl(pos);
 
-                //qDebug() << pos  << "/" << m_fileSize;
+                //qCDebug(KONVERSATION_LOG) << pos  << "/" << m_fileSize;
                 if (pos == m_fileSize)
                 {
-                    qDebug() << "Received final ACK.";
+                    qCDebug(KONVERSATION_LOG) << "Received final ACK.";
                     cleanUp();
                     setStatus(Done);
                     emit done(this);
@@ -572,13 +572,13 @@ namespace Konversation
         void TransferSend::slotGotSocketError(QAbstractSocket::SocketError errorCode)
         {
             stopConnectionTimer();
-            qDebug() << "code =  " << errorCode << " string = " << m_sendSocket->errorString();
+            qCDebug(KONVERSATION_LOG) << "code =  " << errorCode << " string = " << m_sendSocket->errorString();
             failed(i18n("Socket error: %1", m_sendSocket->errorString()));
         }
 
         void TransferSend::startConnectionTimer(int secs)
         {
-            qDebug();
+            qCDebug(KONVERSATION_LOG) << __FUNCTION__;
             //start also restarts, no need for us to double check it
             m_connectionTimer->start(secs * 1000);
         }
@@ -587,18 +587,18 @@ namespace Konversation
         {
             if (m_connectionTimer->isActive())
             {
-                qDebug() << "stop";
+                qCDebug(KONVERSATION_LOG) << "stop";
                 m_connectionTimer->stop();
             }
         }
 
         void TransferSend::slotConnectionTimeout()         // slot
         {
-            qDebug();
+            qCDebug(KONVERSATION_LOG) << __FUNCTION__;
             failed(i18n("Timed out"));
         }
                                                           // protected, static
-        QString TransferSend::getQFileErrorString(int code)
+        QString TransferSend::getQFileErrorString(int code) const
         {
             QString errorString;
 
