@@ -1,13 +1,8 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2004, 2007 Peter Simonsson <psn@linux.se>
-  Copyright (C) 2006-2008 Eike Hein <hein@kde.org>
+    SPDX-FileCopyrightText: 2004, 2007 Peter Simonsson <psn@linux.se>
+    SPDX-FileCopyrightText: 2006-2008 Eike Hein <hein@kde.org>
 */
 
 #include "serverlistdialog.h"
@@ -21,6 +16,7 @@
 
 #include <KGuiItem>
 #include <KMessageBox>
+#include <KSharedConfig>
 
 
 namespace Konversation
@@ -28,11 +24,11 @@ namespace Konversation
     //
     // ServerListItem
     //
-    ServerListItem::ServerListItem( QTreeWidget * tree, QStringList & strings) : QTreeWidgetItem (tree,strings)
+    ServerListItem::ServerListItem( QTreeWidget * tree, const QStringList & strings) : QTreeWidgetItem (tree,strings)
     {
     }
 
-    ServerListItem::ServerListItem( QTreeWidgetItem * parent, QStringList & strings) : QTreeWidgetItem (parent,strings)
+    ServerListItem::ServerListItem( QTreeWidgetItem * parent, const QStringList & strings) : QTreeWidgetItem (parent,strings)
     {
     }
 
@@ -54,47 +50,46 @@ namespace Konversation
     }
 
     ServerListDialog::ServerListDialog(const QString& title, QWidget *parent)
-    : KDialog(parent), Ui::ServerListDialogUI()
+    : QDialog(parent), Ui::ServerListDialogUI()
     {
-        setCaption(title);
-        setButtons(Ok|Close);
+        setWindowTitle(title);
 
-        setupUi(mainWidget());
-        mainWidget()->layout()->setMargin(0);
+        setupUi(this);
 
-        setButtonGuiItem(Ok, KGuiItem(i18n("C&onnect"), "network-connect", i18n("Connect to the server"), i18n("Click here to connect to the selected IRC network and channel.")));
+        KGuiItem::assign(m_buttonBox->button(QDialogButtonBox::Ok), KGuiItem(i18n("C&onnect"), QStringLiteral("network-connect"), i18n("Connect to the server"),
+                                                                             i18n("Click here to connect to the selected IRC network and channel.")));
 
         m_showAtStartup->setChecked(Preferences::self()->showServerList());
-        connect(m_showAtStartup, SIGNAL(toggled(bool)), this, SLOT(setShowAtStartup(bool)));
+        connect(m_showAtStartup, &QCheckBox::toggled, this, &ServerListDialog::setShowAtStartup);
 
         m_serverList->setFocus();
 
         m_selectedItem = false;
-        m_selectedItemPtr = 0;
-        m_selectedServer = ServerSettings("");
+        m_selectedItemPtr = nullptr;
+        m_selectedServer = ServerSettings(QString());
 
         // Load server list
         updateServerList();
 
-        connect(m_serverList, SIGNAL(aboutToMove()), this, SLOT(slotAboutToMove()));
-        connect(m_serverList, SIGNAL(moved()), this, SLOT(slotMoved()));
-        connect(m_serverList, SIGNAL(itemDoubleClicked(QTreeWidgetItem*,int)), this, SLOT(slotOk()));
-        connect(m_serverList, SIGNAL(itemSelectionChanged()), this, SLOT(updateButtons()));
-        connect(m_serverList, SIGNAL(itemExpanded(QTreeWidgetItem*)), this, SLOT(slotSetGroupExpanded(QTreeWidgetItem*)));
-        connect(m_serverList, SIGNAL(itemCollapsed(QTreeWidgetItem*)), this, SLOT(slotSetGroupCollapsed(QTreeWidgetItem*)));
-        connect(m_addButton, SIGNAL(clicked()), this, SLOT(slotAdd()));
-        connect(m_editButton, SIGNAL(clicked()), this, SLOT(slotEdit()));
-        connect(m_delButton, SIGNAL(clicked()), this, SLOT(slotDelete()));
-        connect(this, SIGNAL(okClicked()), this, SLOT(slotOk()));
-        connect(this, SIGNAL(cancelClicked()), this, SLOT(slotClose()));
+        connect(m_serverList, &ServerListView::aboutToMove, this, &ServerListDialog::slotAboutToMove);
+        connect(m_serverList, &ServerListView::moved, this, &ServerListDialog::slotMoved);
+        connect(m_serverList, &ServerListView::itemDoubleClicked, this, &ServerListDialog::slotOk);
+        connect(m_serverList, &ServerListView::itemSelectionChanged, this, &ServerListDialog::updateButtons);
+        connect(m_serverList, &ServerListView::itemExpanded, this, &ServerListDialog::slotSetGroupExpanded);
+        connect(m_serverList, &ServerListView::itemCollapsed, this, &ServerListDialog::slotSetGroupCollapsed);
+        connect(m_addButton, &QPushButton::clicked, this, &ServerListDialog::slotAdd);
+        connect(m_editButton, &QPushButton::clicked, this, &ServerListDialog::slotEdit);
+        connect(m_delButton, &QPushButton::clicked, this, &ServerListDialog::slotDelete);
+        connect(m_buttonBox, &QDialogButtonBox::accepted, this, &ServerListDialog::slotOk);
+        connect(m_buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
 
         updateButtons();
 
-        KConfigGroup config(KGlobal::config(), "ServerListDialog");
+        KConfigGroup config(KSharedConfig::openConfig(), "ServerListDialog");
         QSize newSize = size();
         newSize = config.readEntry("Size", newSize);
         resize(newSize);
-        m_serverList->header()->setMovable(false); // don't let the user reorder the header
+        m_serverList->header()->setSectionsMovable(false); // don't let the user reorder the header
         m_serverList->sortItems(0, Qt::AscendingOrder);
         m_serverList->header()->restoreState(config.readEntry<QByteArray>("ServerListHeaderState", QByteArray()));
         //because it sorts the first column in ascending order by default
@@ -104,22 +99,15 @@ namespace Konversation
 
     ServerListDialog::~ServerListDialog()
     {
-        KConfigGroup config(KGlobal::config(), "ServerListDialog");
+        KConfigGroup config(KSharedConfig::openConfig(), "ServerListDialog");
         config.writeEntry("Size", size());
         config.writeEntry("ServerListHeaderState", m_serverList->header()->saveState());
     }
 
-    void ServerListDialog::slotClose()
-    {
-//         slotApply();
-        accept();
-    }
-
     void ServerListDialog::slotOk()
     {
-        QList<QTreeWidgetItem*> selected = m_serverList->selectedItems();
-        foreach (QTreeWidgetItem* item, selected)
-        {
+        const QList<QTreeWidgetItem*> selected = m_serverList->selectedItems();
+        for (QTreeWidgetItem* item : selected) {
             if (item->data(0,IsServer).toBool())
             {
                 ConnectionSettings settings;
@@ -139,7 +127,7 @@ namespace Konversation
     {
         QPointer<ServerGroupDialog> dlg = new ServerGroupDialog(i18n("New Network"), this);
 
-        if(dlg->exec() == KDialog::Accepted)
+        if(dlg->exec() == QDialog::Accepted)
         {
             addServerGroup(dlg->serverGroupSettings());
 
@@ -164,7 +152,7 @@ namespace Konversation
 
                 if (item->data(0,IsServer).toBool())
                 {
-                    if(dlg->execAndEditServer(serverGroup->serverByIndex(item->data(0,ServerId).toInt())) == KDialog::Accepted)
+                    if(dlg->execAndEditServer(serverGroup->serverByIndex(item->data(0,ServerId).toInt())) == QDialog::Accepted)
                     {
                         delete item;
 
@@ -179,13 +167,13 @@ namespace Konversation
                 }
                 else
                 {
-                    if(dlg->exec() == KDialog::Accepted)
+                    if(dlg->exec() == QDialog::Accepted)
                     {
                         delete item;
 
                         m_selectedItem = true;
                         m_selectedServerGroupId = serverGroup->id();
-                        m_selectedServer = ServerSettings("");
+                        m_selectedServer = ServerSettings(QString());
 
                         *serverGroup = *dlg->serverGroupSettings();
 
@@ -201,7 +189,7 @@ namespace Konversation
     {
         QList<QTreeWidgetItem*> selectedItems;
         // Make sure we're not deleting a network's only servers
-        QTreeWidgetItem* parent = 0;
+        QTreeWidgetItem* parent = nullptr;
         QTreeWidgetItemIterator it(m_serverList, QTreeWidgetItemIterator::Selected);
         while (*it)
         {
@@ -246,10 +234,9 @@ namespace Konversation
 
         // Have fun deleting
         QTreeWidgetItem* rootItem = m_serverList->invisibleRootItem();
-        foreach (QTreeWidgetItem* item, selectedItems)
-        {
+        for (QTreeWidgetItem* item : qAsConst(selectedItems)) {
             if (item == m_selectedItemPtr)
-                m_selectedItemPtr = 0;
+                m_selectedItemPtr = nullptr;
 
             rootItem->removeChild(item);
             if (item->data(0,IsServer).toBool())
@@ -333,7 +320,7 @@ namespace Konversation
         int count = m_serverList->selectedItems().count();
         bool enable = (count > 0);
 
-        enableButtonOk(enable);
+        m_buttonBox->button(QDialogButtonBox::Ok)->setEnabled(enable);
         m_delButton->setEnabled(enable);
 
         enable = (count == 1);
@@ -364,7 +351,7 @@ namespace Konversation
             if (item->data(0,IsServer).toBool())
                 m_selectedServer = Preferences::serverGroupById(m_selectedServerGroupId)->serverByIndex(item->data(0,ServerId).toInt());
             else
-                m_selectedServer = ServerSettings("");
+                m_selectedServer = ServerSettings(QString());
         }
 
         m_serverList->setUpdatesEnabled(false);
@@ -373,7 +360,7 @@ namespace Konversation
         Konversation::ServerGroupHash serverGroups = Preferences::serverGroupHash();
         QHashIterator<int, ServerGroupSettingsPtr> it(serverGroups);
 
-        QTreeWidgetItem* networkItem = 0;
+        QTreeWidgetItem* networkItem = nullptr;
         while(it.hasNext())
         {
             it.next();
@@ -399,22 +386,19 @@ namespace Konversation
         // Produce a list of this server group's channels
         QString channels;
 
-        Konversation::ChannelList channelList = serverGroup->channelList();
-        Konversation::ChannelList::iterator channelIt;
-        Konversation::ChannelList::iterator begin = channelList.begin();
+        const Konversation::ChannelList channelList = serverGroup->channelList();
 
-        for(channelIt = begin; channelIt != channelList.end(); ++channelIt)
-        {
-            if (channelIt != begin)
-                channels += ", ";
+        for (const auto& channel : channelList) {
+            if (!channels.isEmpty())
+                channels += QLatin1String(", ");
 
-            channels += (*channelIt).name();
+            channels += channel.name();
         }
 
         // Insert the server group into the list
-        QTreeWidgetItem* networkItem = new ServerListItem(m_serverList, QStringList() << serverGroup->name()
-                                                                        << serverGroup->identity()->getName()
-                                                                        << channels);
+        QTreeWidgetItem* networkItem = new ServerListItem(m_serverList, QStringList { serverGroup->name(),
+                                                                        serverGroup->identity()->getName(),
+                                                                        channels });
         networkItem->setData(0,ServerGroupId,serverGroup->id());
         networkItem->setData(0,SortIndex,serverGroup->sortIndex());
         networkItem->setData(0,IsServer,false);
@@ -424,30 +408,28 @@ namespace Konversation
             networkItem->setExpanded(true);
 
         // Produce a list of this server group's servers and iterate over it
-        Konversation::ServerList serverList = serverGroup->serverList();
-        Konversation::ServerList::const_iterator serverIt;
+        const Konversation::ServerList serverList = serverGroup->serverList();
 
         int i = 0;
-        for (serverIt = serverList.constBegin(); serverIt != serverList.constEnd(); ++serverIt)
-        {
+        for (const auto& server : serverList) {
             // Produce a string representation of the server object
-            QString name = (*serverIt).host();
+            QString name = server.host();
 
-            if ((*serverIt).port() != 6667)
-                name += ':' + QString::number((*serverIt).port());
+            if (server.port() != 6667)
+                name += QLatin1Char(':') + QString::number(server.port());
 
-            if ((*serverIt).SSLEnabled())
-                name += " (SSL)";
+            if (server.SSLEnabled())
+                name += QLatin1String(" (SSL)");
 
             // Insert the server into the list, as child of the server group list item
-            QTreeWidgetItem* serverItem = new ServerListItem(networkItem, QStringList() << name);
+            QTreeWidgetItem* serverItem = new ServerListItem(networkItem, QStringList { name });
             serverItem->setData(0,ServerGroupId,serverGroup->id());
             serverItem->setData(0,SortIndex,i);
             serverItem->setData(0,IsServer,true);
             serverItem->setData(0,ServerId,i);
             serverItem->setFirstColumnSpanned(true);
             // Initialize a pointer to the new location of the last edited server
-            if (m_selectedItem && m_selectedServer==(*serverIt))
+            if (m_selectedItem && m_selectedServer == server)
                 m_selectedItemPtr = serverItem;
 
             ++i;
@@ -474,4 +456,4 @@ namespace Konversation
     }
 }
 
-#include "serverlistdialog.moc"
+
