@@ -1,15 +1,7 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Shows the content of a log file
-  begin:     Fri Dec 5 2003
-  copyright: (C) 2003 by Dario Abatianni
-  email:     eisfuchs@tigress.com
+    SPDX-FileCopyrightText: 2003 Dario Abatianni <eisfuchs@tigress.com>
 */
 
 #include "logfilereader.h"
@@ -42,23 +34,23 @@ LogfileReader::LogfileReader(QWidget* parent, const QString& log, const QString&
     setSpacing(0);
 
     toolBar = new KToolBar(this, true, true);
-    toolBar->setObjectName("logfile_toolbar");
-    toolBar->addAction(QIcon::fromTheme("document-save-as"), i18n("Save As..."), this, SLOT(saveLog()));
-    toolBar->addAction(QIcon::fromTheme("view-refresh"), i18n("Reload"), this, SLOT(updateView()));
-    toolBar->addAction(QIcon::fromTheme("edit-delete"), i18n("Clear Logfile"), this, SLOT(clearLog()));
+    toolBar->setObjectName(QStringLiteral("logfile_toolbar"));
+    toolBar->addAction(QIcon::fromTheme(QStringLiteral("document-save-as")), i18n("Save As..."), this, &LogfileReader::saveLog);
+    toolBar->addAction(QIcon::fromTheme(QStringLiteral("view-refresh")), i18n("Reload"), this, &LogfileReader::updateView);
+    toolBar->addAction(QIcon::fromTheme(QStringLiteral("edit-delete")), i18n("Clear Logfile"), this, &LogfileReader::clearLog);
 
     toolBar->addWidget(new QLabel(i18n("Show last:"),toolBar));
     sizeSpin = new QSpinBox(toolBar);
     sizeSpin->setMinimum(10);
     sizeSpin->setMaximum(1000);
     sizeSpin->setSingleStep(10);
-    sizeSpin->setObjectName("logfile_size_spinbox");
+    sizeSpin->setObjectName(QStringLiteral("logfile_size_spinbox"));
     sizeSpin->setWhatsThis(i18n("Use this box to set the maximum size of the log file. This setting does not take effect until you restart Konversation. Each log file may have a separate setting."));
     sizeSpin->setValue(Preferences::self()->logfileBufferSize());
     sizeSpin->setSuffix(i18n(" KB"));
     sizeSpin->installEventFilter(this);
     toolBar->addWidget(sizeSpin);
-    connect(sizeSpin, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &LogfileReader::storeBufferSize);
+    connect(sizeSpin, QOverload<int>::of(&QSpinBox::valueChanged), this, &LogfileReader::storeBufferSize);
 
     IRCViewBox* ircBox = new IRCViewBox(this);
     setTextView(ircBox->ircView());
@@ -71,18 +63,18 @@ LogfileReader::LogfileReader(QWidget* parent, const QString& log, const QString&
 
     updateAppearance();
 
-    connect(getTextView(), SIGNAL(gotFocus()), getTextView(), SLOT(setFocus()));
+    connect(getTextView(), &IRCView::gotFocus, getTextView(), QOverload<>::of(&IRCView::setFocus));
 }
 
 LogfileReader::~LogfileReader()
 {
 }
 
-bool LogfileReader::eventFilter(QObject* /* watched */, QEvent* e)
+bool LogfileReader::eventFilter(QObject* watched, QEvent* e)
 {
     if (e->type() == QEvent::KeyPress)
     {
-        QKeyEvent* ke = static_cast<QKeyEvent*>(e);
+        auto* ke = static_cast<QKeyEvent*>(e);
 
         if (ke->key() == Qt::Key_Return || ke->key() == Qt::Key_Enter)
         {
@@ -94,7 +86,7 @@ bool LogfileReader::eventFilter(QObject* /* watched */, QEvent* e)
             return false;
     }
 
-    return false;
+    return ChatWindow::eventFilter(watched, e);
 }
 
 void LogfileReader::storeBufferSize(int kb)
@@ -133,7 +125,7 @@ void LogfileReader::updateView()
             getTextView()->appendLog(str);
         }
 
-        stream.setDevice(0);
+        stream.setDevice(nullptr);
         file.close();
     }
 }
@@ -145,7 +137,7 @@ void LogfileReader::clearLog()
         i18n("Clear Logfile"),
         KStandardGuiItem::del(),
         KStandardGuiItem::cancel(),
-        "ClearLogfileQuestion")==KMessageBox::Continue)
+        QStringLiteral("ClearLogfileQuestion"))==KMessageBox::Continue)
     {
         QFile::remove(fileName);
         updateView();
@@ -157,7 +149,7 @@ void LogfileReader::saveLog()
     KMessageBox::information(this,
         i18n("Note: By saving the logfile you will save all data in the file, not only the part you can see in this viewer."),
         i18n("Save Logfile"),
-        "SaveLogfileNote");
+        QStringLiteral("SaveLogfileNote"));
 
     QUrl logUrl = QUrl::fromLocalFile(fileName);
     QUrl destination = QFileDialog::getSaveFileUrl(this, i18n("Choose Destination Folder"), logUrl);
@@ -186,14 +178,4 @@ void LogfileReader::childAdjustFocus()
   getTextView()->setFocus();
 }
 
-int LogfileReader::margin()
-{
-    return style()->pixelMetric(QStyle::PM_LayoutLeftMargin);
-}
-
-int LogfileReader::spacing()
-{
-    return style()->layoutSpacing(QSizePolicy::DefaultType, QSizePolicy::DefaultType, Qt::Horizontal);
-}
-
-bool LogfileReader::searchView() { return true; }
+bool LogfileReader::searchView() const { return true; }
